
import { AlertCircle, CheckCircle2 } from 'lucide-react';
import { cn } from '@/lib/utils';

interface PredictionCardProps {
  riskScore: number;
  defaultProbability: number;
  clientName: string;
}

const PredictionCard = ({ riskScore, defaultProbability, clientName }: PredictionCardProps) => {
  const isHighRisk = riskScore > 60;
  
  // Determine risk level
  const getRiskLevel = (score: number) => {
    if (score < 20) return { label: 'Very Low Risk', color: 'text-green-600', bgColor: 'bg-green-50' };
    if (score < 40) return { label: 'Low Risk', color: 'text-emerald-600', bgColor: 'bg-emerald-50' };
    if (score < 60) return { label: 'Moderate Risk', color: 'text-yellow-600', bgColor: 'bg-yellow-50' };
    if (score < 80) return { label: 'High Risk', color: 'text-orange-600', bgColor: 'bg-orange-50' };
    return { label: 'Very High Risk', color: 'text-red-600', bgColor: 'bg-red-50' };
  };

  const riskLevel = getRiskLevel(riskScore);
  const willDefault = defaultProbability > 0.5;

  return (
    <div className="glass-panel overflow-hidden">
      <div className="p-6">
        <div className="mb-4">
          <span className="text-sm text-muted-foreground">Client Name</span>
          <h3 className="text-xl font-semibold">{clientName}</h3>
        </div>
        
        <div className="flex flex-col gap-6">
          {/* Default Prediction */}
          <div>
            <span className="text-sm text-muted-foreground">Default Prediction</span>
            <div className="flex items-center mt-1">
              {willDefault ? (
                <>
                  <AlertCircle className="w-5 h-5 text-red-500 mr-2" />
                  <span className="font-semibold text-red-500">High Default Risk</span>
                </>
              ) : (
                <>
                  <CheckCircle2 className="w-5 h-5 text-green-500 mr-2" />
                  <span className="font-semibold text-green-500">Low Default Risk</span>
                </>
              )}
            </div>
            <div className="text-sm text-muted-foreground mt-1">
              {(defaultProbability * 100).toFixed(1)}% probability of default
            </div>
          </div>
          
          {/* Risk Score */}
          <div className="mb-2">
            <div className="flex justify-between items-center mb-1">
              <span className="text-sm text-muted-foreground">Risk Score</span>
              <span className={cn("text-sm font-medium px-2 py-0.5 rounded-full", riskLevel.bgColor, riskLevel.color)}>
                {riskLevel.label}
              </span>
            </div>
            
            <div className="relative w-full h-4 bg-gray-100 rounded-full overflow-hidden">
              <div 
                className={cn(
                  "absolute top-0 left-0 h-full rounded-full transition-all duration-1000 ease-out",
                  isHighRisk ? "bg-gradient-to-r from-yellow-400 to-red-500" : "bg-gradient-to-r from-cyan-400 to-brand-blue"
                )}
                style={{ width: `${riskScore}%` }}
              ></div>
            </div>
            
            <div className="mt-1 text-lg font-semibold">
              {riskScore} <span className="text-sm text-muted-foreground font-normal">/ 100</span>
            </div>
          </div>
        </div>
      </div>
      
      <div className={cn(
        "px-6 py-3 text-center text-sm font-medium",
        isHighRisk ? "bg-red-50 text-red-700" : "bg-green-50 text-green-700"
      )}>
        {isHighRisk 
          ? "Caution: Higher than average risk detected" 
          : "Good standing: Lower than average risk detected"}
      </div>
    </div>
  );
};

export default PredictionCard;
